import { KernelMessage } from '@jupyterlab/services';
import { BaseKernel, IKernel } from '@jupyterlite/kernel';
import { IRemoteJavaScriptWorkerKernel } from './tokens';
/**
 * A kernel that executes code in an IFrame.
 */
export declare class JavaScriptKernel extends BaseKernel implements IKernel {
    /**
     * Instantiate a new JavaScriptKernel
     *
     * @param options The instantiation options for a new JavaScriptKernel
     */
    constructor(options: JavaScriptKernel.IOptions);
    /**
     * Dispose the kernel.
     */
    dispose(): void;
    /**
     * A promise that is fulfilled when the kernel is ready.
     */
    get ready(): Promise<void>;
    /**
     * Handle a kernel_info_request message
     */
    kernelInfoRequest(): Promise<KernelMessage.IInfoReplyMsg['content']>;
    /**
     * Handle an `execute_request` message
     *
     * @param msg The parent message.
     */
    executeRequest(content: KernelMessage.IExecuteRequestMsg['content']): Promise<KernelMessage.IExecuteReplyMsg['content']>;
    /**
     * Handle an complete_request message
     *
     * @param msg The parent message.
     */
    completeRequest(content: KernelMessage.ICompleteRequestMsg['content']): Promise<KernelMessage.ICompleteReplyMsg['content']>;
    /**
     * Handle an `inspect_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    inspectRequest(content: KernelMessage.IInspectRequestMsg['content']): Promise<KernelMessage.IInspectReplyMsg['content']>;
    /**
     * Handle an `is_complete_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    isCompleteRequest(content: KernelMessage.IIsCompleteRequestMsg['content']): Promise<KernelMessage.IIsCompleteReplyMsg['content']>;
    /**
     * Handle a `comm_info_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    commInfoRequest(content: KernelMessage.ICommInfoRequestMsg['content']): Promise<KernelMessage.ICommInfoReplyMsg['content']>;
    /**
     * Send an `input_reply` message.
     *
     * @param content - The content of the reply.
     */
    inputReply(content: KernelMessage.IInputReplyMsg['content']): void;
    /**
     * Send an `comm_open` message.
     *
     * @param msg - The comm_open message.
     */
    commOpen(msg: KernelMessage.ICommOpenMsg): Promise<void>;
    /**
     * Send an `comm_msg` message.
     *
     * @param msg - The comm_msg message.
     */
    commMsg(msg: KernelMessage.ICommMsgMsg): Promise<void>;
    /**
     * Send an `comm_close` message.
     *
     * @param close - The comm_close message.
     */
    commClose(msg: KernelMessage.ICommCloseMsg): Promise<void>;
    /**
     * Load the worker.
     *
     * ### Note
     *
     * Subclasses must implement this typographically almost _exactly_ for
     * webpack to find it.
     */
    protected initWorker(options: JavaScriptKernel.IOptions): Worker;
    /**
     * Initialize the remote kernel.
     *
     * @param options The options for the remote kernel.
     * @returns The initialized remote kernel.
     */
    protected initRemote(options: JavaScriptKernel.IOptions): IRemoteJavaScriptWorkerKernel;
    /**
     * Process a message coming from the JavaScript web worker.
     *
     * @param msg The worker message to process.
     */
    private _processWorkerMessage;
    protected remoteKernel: IRemoteJavaScriptWorkerKernel;
    private _worker;
    private _ready;
}
/**
 * A namespace for JavaScriptKernel statics
 */
declare namespace JavaScriptKernel {
    /**
     * The instantiation options for a JavaScript kernel.
     */
    interface IOptions extends IKernel.IOptions {
    }
}
export {};
